#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <pspctrl.h>
#include <pspdebug.h>
#include <pspkernel.h>

#include "unzip.h"

#include "common.h"
#include "imgview.h"
#include "etcfunc.h"

int cfg_init (zipinfo_t * zipinfo)
{
int ret;
char tmpvalue [BUF_128];
SceUID cfgfd;

	// file open
	cfgfd = sceIoOpen (CFG_FILE, PSP_O_RDONLY, 0777);
	if (cfgfd < 0)
	{
		pprintf ("file not found [%s]\n", CFG_FILE);
		return (FAILURE);
	}

	// get cache size
	memset (tmpvalue, 0x00, sizeof (tmpvalue));
	ret = get_config (cfgfd, "CACHE_SIZE", tmpvalue);
	if (ret != SUCCESS)
	{
		sceIoClose (cfgfd);
		pprintf ("get_config () failed [%s]\n", "CACHE_SIZE");
		return (FAILURE);
	}
	zipinfo -> bufcnt = atoi (tmpvalue);

	// file colse
	sceIoClose (cfgfd);

	return (SUCCESS);
}

int get_config (SceUID cfgfd, char * token, char * value)
{
int ret;
char * keypos;
char cfgbuf [BUF_1024];

	// reset offset
	sceIoLseek32 (cfgfd, 0, SEEK_SET);

	// read file
	memset (cfgbuf, 0x00, sizeof (cfgbuf));
	ret = sceIoRead (cfgfd, (void *)cfgbuf, sizeof (cfgbuf) - 1);
	if (ret < 1)
	{
		pprintf ("sceIoRead () failed\n");
		return (FAILURE);
	}

	// find out pos of token
	keypos = strstr (cfgbuf, token);
	if (keypos == NULL)
	{
		pprintf ("key [%s] not found in %s\n", token, CFG_FILE);
		return (FAILURE);
	}

	// read value
	sscanf (keypos, "%s = %[^\r^\n^#^/]", token, value);

	return (SUCCESS);
}

/*
int get_dirinfo (char * path, dirinfo_t * dirinfo)
{
int ret;
int entcnt;
char * tmpbuf;
DIR * dir;
struct dirent * entry;

	dir = opendir (path);
	if (dir == NULL)
	{
		pprintf ("can not open dir. [%s]\n", path);
		return (FAILURE);
	}

	dirinfo -> filecnt = 0;
	while (TRUE)
	{
		entry = readdir (dir)
		if (entry == NULL)
		{
			break;
		}

		// 1 means NULL
		tmpbuf = malloc (strlen (entry -> d_name) + 1);
		if (tmpbuf == NULL)
		{
			pprintf ("malloc () failed [%dbyte]\n", strlen (entry -> d_name));
			return (FAILURE);
		}

		// filename copy
		dirinfo -> filenames [dirinfo -> filecnt] = tmpbuf;
		dirinfo -> filetypes [dirinfo -> filecnt] = entry -> d_stat.st_attr & FIO_SO_IFDIR;
	}
}
*/

int get_event (int * opcode)
{
SceCtrlData ctrlpad;

	sceCtrlReadBufferPositive (&ctrlpad, 1);

	// analog pad event
	if (ctrlpad.Buttons == 0)
	{
	}

	// button event
	if (ctrlpad.Buttons != 0)
	{
		if (ctrlpad.Buttons & PSP_CTRL_START)		*opcode = OPCODE_NONE;
		if (ctrlpad.Buttons & PSP_CTRL_SELECT)		*opcode = OPCODE_NONE;
		if (ctrlpad.Buttons & PSP_CTRL_LTRIGGER)	*opcode = OPCODE_PREV;
		if (ctrlpad.Buttons & PSP_CTRL_RTRIGGER)	*opcode = OPCODE_NEXT;
	
		if (ctrlpad.Buttons & PSP_CTRL_UP)			*opcode = OPCODE_NONE;
		if (ctrlpad.Buttons & PSP_CTRL_DOWN)		*opcode = OPCODE_NONE;
		if (ctrlpad.Buttons & PSP_CTRL_LEFT)		*opcode = OPCODE_PREV;
		if (ctrlpad.Buttons & PSP_CTRL_RIGHT)		*opcode = OPCODE_NEXT;

		if (ctrlpad.Buttons & PSP_CTRL_SQUARE)		*opcode = OPCODE_NONE;
		if (ctrlpad.Buttons & PSP_CTRL_TRIANGLE)	*opcode = OPCODE_NONE;
		if (ctrlpad.Buttons & PSP_CTRL_CIRCLE)		*opcode = OPCODE_NONE;
		if (ctrlpad.Buttons & PSP_CTRL_CROSS)		*opcode = OPCODE_EXIT;
	}

	return (SUCCESS);
}
