#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <pspdebug.h>
#include <pspkernel.h>

#include <SDL/SDL.h>
#include <SDL/SDL_image.h>

#include "unzip.h"

#include "common.h"
#include "imgview.h"
#include "etcfunc.h"
#include "zipfunc.h"
#include "sdlfunc.h"
#include "thrdfunc.h"

int main (int argc, char * argv [])
{
int ret;
int opcode;
int imgidx;
zipinfo_t zipinfo;

	// init variables
	memset (&zipinfo, 0x00, sizeof (zipinfo_t));

	// init screen
	pspDebugScreenInit ();

	// setting callback thread
	SetupCallbacks ();

	// load config
	ret = cfg_init (&zipinfo);
	if (ret != SUCCESS)
	{
		pprintf ("cfg_init () failed\n");
		goto EXIT_PROC;
	}

	// select zip file
	ret = select_zip (&zipinfo);
	if (ret != SUCCESS)
	{
		pprintf ("select_zip () failed\n");
		goto EXIT_PROC;
	}

	// open zipfile
	// extract filename list
	// find out max file size
	ret = zip_init (&zipinfo);
	if (ret != SUCCESS)
	{
		pprintf ("zip_init () failed\n");
		goto EXIT_PROC;
	}

	ret = sdl_init ();
	if (ret != SUCCESS)
	{
		pprintf ("sdl_init () failed.\n");
		goto EXIT_PROC;
	}

	imgidx = 0;
	while (TRUE)
	{
		// 1 means case sensitivity
		ret = unzLocateFile (zipinfo.zipfd, zipinfo.filenames [imgidx], 1);
		if (ret != UNZ_OK)
		{
			pprintf ("unzLocateFile () failed. [%s]\n", zipinfo.filesizes [imgidx]);
			goto EXIT_PROC;
		}

		// open read close each file from zip file
		unzOpenCurrentFile (zipinfo.zipfd);
		ret = unzReadCurrentFile (zipinfo.zipfd, (void *)zipinfo.imgbufs [0], zipinfo.filesizes [imgidx]);
		unzCloseCurrentFile (zipinfo.zipfd);
		if (ret != zipinfo.filesizes [imgidx])
		{
			pprintf ("unzReadCurrentFile () failed. [%s]\n", zipinfo.filenames [imgidx]);
			goto EXIT_PROC;
		}

		ret = sdl_show (zipinfo.imgbufs [0], zipinfo.filesizes [imgidx]);
		if (ret != SUCCESS)
		{
			pprintf ("showimage () failed. [%s(%dbytes)]\n", zipinfo.filenames [imgidx], zipinfo.filesizes [imgidx]);
			goto EXIT_PROC;
		}

		// decide next operation
		while (TRUE)
		{
			opcode = 0;
			get_event (&opcode);

			if (opcode == OPCODE_NONE)
			{
				continue;
			}

			if (opcode == OPCODE_NEXT _AND_ (imgidx + 1) != zipinfo.filecnt)
			{
				imgidx ++;
				break;
			}

			if (opcode == OPCODE_PREV _AND_ (imgidx - 1) != -1)
			{
				imgidx --;
				break;
			}

			if (opcode == OPCODE_UP)
			{
			}

			if (opcode == OPCODE_DOWN)
			{
			}

			if (opcode == OPCODE_LEFT)
			{
			}

			if (opcode == OPCODE_RIGHT)
			{
			}

			if (opcode == OPCODE_EXIT)
			{
				goto EXIT_PROC;
			}
		}
	} // end of while

EXIT_PROC :

	sdl_exit ();
	zip_free (&zipinfo);

	return (SUCCESS);
}
