#include <stdio.h> 
#include <stdlib.h> 
#include <string.h> 
#include <stdarg.h> 

#include <SDL/SDL.h> 
#include <SDL/SDL_image.h> 

#include "common.h" 
#include "sdlfunc.h"

int get_error (char * buffer, int size) 
{ 
int len; 
char * tmp; 

	tmp = SDL_GetError (); 
	len = strlen (tmp); 
	len = (len >= size) ? size - 1 : len; 

	memset (buffer, 0x00, size); 
	memcpy (buffer, tmp, len); 
} 

int print_log (const char * msgstr, ...) 
{ 
va_list args; 
char buffer [BUF_1024]; 

	// formatting SDL error message 
	va_start (args, msgstr); 
	vsprintf(buffer, msgstr, args); 
	va_end (args); 

	// print error message 
	pprintf ("%s", buffer); 

	// set point to next line 
	psetxy (0, pgety () + 1); 

	return (SUCCESS); 
} 

int sdl_init (void)
{
int ret;
SDL_Surface * screen;

    // initialize SDL
	ret = SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER);
    if(ret != SUCCESS)
    {
        return (FAILURE);
    }

    // initialize PSP screen
    SDL_ShowCursor (SDL_DISABLE);
    screen = SDL_SetVideoMode (480, 272, 0, SDL_HWSURFACE | SDL_DOUBLEBUF);
    if (screen == NULL)
    {
        return (FAILURE);
    }

	return (SUCCESS);
}

int sdl_exit (void)
{
	SDL_Quit ();
}

int sdl_show (char * imgbuf, int size)
{
int ret;

SDL_Rect src;
SDL_Rect dest;
SDL_RWops * imgRWops;
SDL_Surface * image;
SDL_Surface * screen;

	imgRWops = SDL_RWFromMem (imgbuf, size);
	if (imgRWops == NULL)
	{
		pprintf ("SDL_RWFromMem () failed.\n");
	}

	// 1 means free imgRWops after use.
	image = IMG_Load_RW (imgRWops, 1);
	if (image == NULL)
	{
		pprintf ("IMG_Load_RW () failed.\n");
		goto EXIT_FUNC;
	}

	screen = SDL_GetVideoSurface ();
	if (screen == NULL)
	{
		pprintf ("SDL_GetVideoSurface () failed.\n");
		goto EXIT_FUNC;
	}

    // show out to screen
    src.x = dest.x = 0;
    src.y = dest.y = 0;
    src.w = dest.w = screen -> w;
    src.h = dest.h = screen -> h;

	// blitting and free surface
    ret = SDL_BlitSurface (image, &src, screen, &dest);
    if (ret != SUCCESS)
    {
		pprintf ("SDL_BlitSurface () failed.\n");
		goto EXIT_FUNC;
    }
	SDL_FreeSurface (image);

	// flip
    SDL_Flip (screen);

	return (SUCCESS);

EXIT_FUNC :

	SDL_FreeSurface (image);
	return (FAILURE);
}

int sdl_clear (void)
{
SDL_Surface * screen;

	screen = SDL_GetVideoSurface ();
	if (screen == NULL)
	{
		pprintf ("SDL_GetVideoSurface () failed.\n");
		return (FAILURE);
	}

	SDL_FillRect (screen, NULL, SDL_MapRGB (screen -> format, 0, 0, 0));
	SDL_Flip (screen);

	return (SUCCESS);
}
