#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "unzip.h"

#include "common.h"
#include "imgview.h"
#include "zipfunc.h"

int zip_init (zipinfo_t * zipinfo)
{
int ret;
int idx;
char tmpfname [BUF_FNAME];
unz_file_info zfilenames;

	// open zip file
	zipinfo -> zipfd = unzOpen (zipinfo -> zippath);
	if (zipinfo -> zipfd == NULL)
	{
		pprintf ("unzOpen () failed : [%s]\n", zipinfo -> zippath);
		return (FAILURE);
	}

	while (TRUE)
	{
		// get file info
		memset (&tmpfname, 0x00, sizeof (tmpfname));
		memset (&zfilenames, 0x00, sizeof (zfilenames));
		ret = unzGetCurrentFileInfo (zipinfo -> zipfd, &zfilenames, tmpfname, sizeof (tmpfname), NULL, 0, NULL, 0);
		if (ret != UNZ_OK)
		{
			pprintf ("unzGetCurrentFileInfo () failed\n");
			return (FAILURE);
		}

		// check filename length
		if (tmpfname [sizeof (tmpfname) - 1] != '\0')
		{
			pprintf ("filename is too long\n");
			return (FAILURE);
		}

		// save filename and filesizes
		zipinfo -> filenames [zipinfo -> filecnt] = (char *)malloc (strlen (tmpfname) + 1);
		if (zipinfo -> filenames [zipinfo -> filecnt] == NULL)
		{
			pprintf ("malloc () failed. [%dbyte]\n", strlen (tmpfname) + 1);
			return (FAILURE);
		}
		memset (zipinfo -> filenames [zipinfo -> filecnt], 0x00, strlen (tmpfname) + 1);
		memcpy (zipinfo -> filenames [zipinfo -> filecnt], tmpfname, strlen (tmpfname));
		zipinfo -> filesizes [zipinfo -> filecnt] = zfilenames.uncompressed_size;
		zipinfo -> filecnt ++;

		// calc max filesizes
		zipinfo -> bufsize = (zfilenames.uncompressed_size > zipinfo -> bufsize) ? zfilenames.uncompressed_size : zipinfo -> bufsize;

		// goto next
		ret = unzGoToNextFile (zipinfo -> zipfd);
		if (ret != UNZ_OK)
		{
			break;
		}
	}

	// malloc for image buffer by cache size
	for (idx = 0; idx < zipinfo -> bufcnt; idx ++)
	{
		zipinfo -> imgbufs [idx] = (char *)malloc (zipinfo -> bufsize);
		if (zipinfo -> imgbufs [idx] == NULL)
		{
			pprintf ("malloc () failed. [%d]\n", zipinfo -> bufsize);
			return (FAILURE);
		}
	}

	return (SUCCESS);;
}

int zip_free (zipinfo_t * zipinfo)
{
int idx;

	// close zip file
	if (zipinfo -> zipfd != NULL)
	{
		unzClose (zipinfo -> zipfd);
	}

	// free filename list
	for (idx = 0; idx < zipinfo -> filecnt; idx ++)
	{
		if (zipinfo -> filenames [idx] != NULL)
		{
			free (zipinfo -> filenames [idx]);
		}
	}

	// free image buffers
	for (idx = 0; idx < zipinfo -> bufcnt; idx ++)
	{
		if (zipinfo -> imgbufs [idx] != NULL)
		{
			free (zipinfo -> imgbufs [idx]);
		}
	}

	// reset variable
	memset (zipinfo, 0x00, sizeof (zipinfo_t));

	return (SUCCESS);;
}

int select_zip (zipinfo_t * zipinfo)
{
	sprintf (zipinfo -> zippath, "test.zip"); 

	return (SUCCESS);;
}


